@@ -34,6 +34,6 @@ from inveniofab.mysql import mysql_dropdb, mysql_createdb, mysql_load, \
     mysql_dump, mysql_copy
 from inveniofab.test import test_load, test_dump, test_clean, test_reset_admin
 from inveniofab.venv import venv_create, venv_dump, venv_load, venv_drop, \
-    venv_requirements
+    venv_requirements, venv_pyuno_install
 from inveniofab.compound import bootstrap, install, dump, load, drop
 from inveniofab.devserver import devserver_conf, devserver_install_flask
\ No newline at end of file
