@@ -20,11 +20,15 @@ Task for checking out source code from a repository, and running configure,
 make on it.
 """
 
-from fabric.api import task, puts, env, settings, local, abort
+from fabric.api import task, puts, env, settings, local, abort, hide
 from fabric.contrib.console import confirm
 from fabric.colors import cyan, red
 import os
 
+#
+# Tasks
+#
+
 @task
 def repo_configure(repo):
     """ Configure repository """
@@ -37,12 +41,7 @@ def repo_configure(repo):
     }
     ctx.update(env)
 
-    if os.path.exists(os.path.join(topsrcdir, "configure")):
-        with settings(warn_only=True):
-            local("cd %(topsrcdir)s && make -s clean" % ctx)
-    local("cd %(topsrcdir)s && ./configure --prefix=%(CFG_INVENIO_PREFIX)s "
-          "--with-python=%(CFG_INVENIO_PREFIX)s/bin/python" % ctx)
-    local("cd %(topsrcdir)s && make -s clean" % ctx)
+    _run_hook(repo, 'configure_hook', default_configure_hook, ctx)
 
 
 @task
@@ -77,7 +76,11 @@ def repo_install(repo=None, targets_key='install_targets'):
 def repo_prepare(repo=None):
     """ Prepare source code after fresh checkout """
     topsrcdir = repo_check(repo, workdir=True)
-    local("cd %s; aclocal && automake -a && autoconf -f" % topsrcdir)
+
+    ctx = {'topsrcdir': topsrcdir}
+    ctx.update(env)
+
+    _run_hook(repo, 'prepare_hook', default_prepare_hook, ctx)
 
 
 @task
@@ -121,7 +124,7 @@ def repo_update(**kwargs):
             ref = kwargs[repo]
             if not ref:
                 ref = None
-            repo_refs.append(repo, ref)
+            repo_refs.append((repo, ref))
             del kwargs[repo]
         else:
             try:
@@ -229,7 +232,19 @@ def git_newworkdir(repo):
         local("%(CFG_INVENIO_PREFIX)s/bin/git-new-workdir %(srcdir)s %(srcworkdir)s" % ctx)
 
 
+def git_isdirty(dir):
+    """
+    Check working directory for uncommitted changes
+    """
+    with settings(hide('everything'), warn_only=True):
+        output = local("cd %s && git diff-index --exit-code HEAD --" % dir, capture=True)
+    return output.return_code != 0
+
+
 def git_checkout(repo, ref):
+    """
+    Checkout a specific git reference.
+    """
     topsrcdir = repo_check(repo, workdir=True)
 
     ctx = {
@@ -238,8 +253,14 @@ def git_checkout(repo, ref):
     }
     ctx.update(env)
 
-    # Stash away any uncomitted changes
-    local("cd %(topsrcdir)s; if ! git diff-index --quiet HEAD --; then git stash; fi; git checkout -f %(ref)s" % ctx)
+    # Stash uncommited changes
+    if git_isdirty(topsrcdir):
+        if not confirm("Working directory %(topsrcdir)s contains uncommited changes. Do you want to stash the changes (required to continue)?" % ctx ):
+            abort("Cannot continue unless uncommitted changes are stashed")
+        else:
+            local("cd %(topsrcdir)s; git stash" % ctx)
+
+    local("cd %(topsrcdir)s; git checkout -f %(ref)s" % ctx)
 
 
 def git_clone(repo):
@@ -276,3 +297,45 @@ def git_clone(repo):
 def git_fetch(repo):
     topsrcdir = repo_check(repo)
     local("cd %s; git fetch origin" % topsrcdir)
+
+
+#
+# Helpers
+#
+def _run_hook(repo, hook_name, default_hook, *args, **kwargs):
+    """
+    Execute a hook for a given repository. If no hook exists, run the default
+    hook.
+    """
+    try:
+        hook = dict(env.CFG_INVENIO_REPOS)[repo][hook_name]
+    except KeyError:
+        hook = default_hook
+
+    if hook:
+        puts(">>> Running hook %s" % hook.__name__)
+        hook(*args, **kwargs)
+    else:
+        puts(">>> No hook found for %s" % hook_name)
+
+#
+# Built-in hooks
+#
+def default_configure_hook(ctx):
+    """
+    Default way to configure a repo. Assumes repo has a configure script.
+    """
+    if os.path.exists(os.path.join(ctx['topsrcdir'], "configure")):
+        with settings(warn_only=True):
+            local("cd %(topsrcdir)s && make -s clean" % ctx)
+    local("cd %(topsrcdir)s && ./configure --prefix=%(CFG_INVENIO_PREFIX)s "
+          "--with-python=%(CFG_INVENIO_PREFIX)s/bin/python" % ctx)
+    local("cd %(topsrcdir)s && make -s clean" % ctx)
+
+
+def default_prepare_hook(ctx):
+    """
+    Default way to prepare source code which uses autotools.
+    """
+    if os.path.exists(os.path.join(ctx['topsrcdir'], "configure.ac")):
+        local("cd %(topsrcdir)s; aclocal && automake -a && autoconf -f" % ctx)
